/**
 * Type union for an enum value.
 *
 * @public
 */
export declare type MixedValue = string | number;
/**
 * Type union of all the values an enum can be made from.
 *
 * @public
 */
export declare type EnumValue<T = MixedValue> = {
    [key: string]: string | number;
} | T[] | Map<string | number, T> | Set<T>;
declare type GetValueType<T> = T extends string[] ? string : T extends number[] ? number : T extends Set<string> ? string : T extends Set<number> ? number : T extends Map<MixedValue, string> ? string : T extends Map<MixedValue, number> ? number : T extends {
    [key: string]: string;
} ? string : T extends {
    [key: string]: number;
} ? number : MixedValue;
/**
 * Enum util methods.
 *
 * @public
 */
export declare const EnumUtils: {
    /**
     * Returns an array of key/values of the enumerable properties of an enum.
     *
     * @public
     * @param e — Enum value.
     */
    entries<T = unknown>(e: T): [string, GetValueType<T>][];
    /**
     * Returns the names of the enumerable properties and methods of an enum.
     *
     * @public
     * @param e - Enum value.
     */
    keys<T = unknown>(e: T): string[];
    /**
     * Returns a value to key mapping object for the input enum.
     *
     * Note: Reverse mapping keys are omitted.
     *
     * @public
     * @param e - Enum value.
     */
    keysByValue<T = unknown>(e: T): {
        [key: string]: string;
    };
    /**
     * Returns an array of values of the enumerable properties of an enum.
     *
     * @public
     * @param e - Enum value.
     */
    values<T = unknown>(e: T): GetValueType<T>[];
    /**
     * Returns a key -> value mapping object for the input enum.
     *
     * Note: Reverse mapping keys are omitted.
     *
     * @public
     * @param e - Enum value.
     */
    valuesByKey<T = unknown>(input: T): {
        [key: string]: GetValueType<T>;
    };
};
/**
 * @public
 */
export default EnumUtils;
